@@ -160,8 +160,8 @@ class Game(object):
 
     .. attribute:: objects
 
-       A dictionary containing all :class:`sge.StellarClass` objects in
-       the game, indexed by the objects' :attr:`sge.StellarClass.id`
+       A dictionary containing all :class:`sge.Object` objects in
+       the game, indexed by the objects' :attr:`sge.Object.id`
        attributes.  (Read-only)
 
     .. attribute:: rooms
@@ -175,12 +175,12 @@ class Game(object):
 
     .. attribute:: mouse
 
-       A :class:`sge.StellarClass` object which represents the mouse
-       cursor.  Its :attr:`sge.StellarClass.id` attribute is ``"mouse"``
+       A :class:`sge.Object` object which represents the mouse
+       cursor.  Its :attr:`sge.Object.id` attribute is ``"mouse"``
        and its bounding box is a one-pixel square.  Speed variables are
        determined by averaging all mouse movement during the last
        quarter of a second.  Assigning to its
-       :attr:`sge.StellarClass.visible` attribute controls whether or
+       :attr:`sge.Object.visible` attribute controls whether or
        not the mouse cursor is shown.  Setting its sprite sets the mouse
        cursor to that sprite.
 
@@ -399,8 +399,6 @@ class Game(object):
           position the imaginary rectangle containing the ellipse.
         - ``width`` -- The width of the ellipse.
         - ``height`` -- The height of the ellipse.
-        - ``fill`` -- The color of the fill of the ellipse.
-        - ``outline`` -- The color of the outline of the ellipse.
         - ``outline_thickness`` -- The thickness of the outline of the
           ellipse.
         - ``anti_alias`` -- Whether or not anti-aliasing should be used.
@@ -445,8 +443,8 @@ class Game(object):
         # TODO
 
     def project_text(self, font, text, x, y, width=None, height=None,
-                    color="black", halign=sge.ALIGN_LEFT, valign=sge.ALIGN_TOP,
-                    anti_alias=True):
+                    color=sge.Color("black"), halign=sge.ALIGN_LEFT,
+                    valign=sge.ALIGN_TOP, anti_alias=True):
         """Project text onto the game window.
 
         Arguments:
@@ -652,7 +650,7 @@ class Game(object):
         """Default mouse collision event.
 
         Proxy for :meth:`sge.game.mouse.event_collision`.  See the
-        documentation for :meth:`sge.StellarClass.event_collision` for
+        documentation for :meth:`sge.Object.event_collision` for
         more information.
 
         """
@@ -662,7 +660,7 @@ class Game(object):
         """Left mouse collision event.
 
         Proxy for :meth:`sge.game.mouse.event_collision_left`.  See the
-        documentation for :meth:`sge.StellarClass.event_collision_left`
+        documentation for :meth:`sge.Object.event_collision_left`
         for more information.
 
         """
@@ -672,7 +670,7 @@ class Game(object):
         """Right mouse collision event.
 
         Proxy for :meth:`sge.game.mouse.event_collision_right`.  See the
-        documentation for :meth:`sge.StellarClass.event_collision_right`
+        documentation for :meth:`sge.Object.event_collision_right`
         for more information.
 
         """
@@ -682,7 +680,7 @@ class Game(object):
         """Top mouse collision event.
 
         Proxy for :meth:`sge.game.mouse.event_collision_top`.  See the
-        documentation for :meth:`sge.StellarClass.event_collision_top`
+        documentation for :meth:`sge.Object.event_collision_top`
         for more information.
 
         """
@@ -693,7 +691,7 @@ class Game(object):
 
         Proxy for :meth:`sge.game.mouse.event_collision_bottom`.  See
         the documentation for
-        :meth:`sge.StellarClass.event_collision_bottom` for more
+        :meth:`sge.Object.event_collision_bottom` for more
         information.
 
         """
