@@ -17,17 +17,16 @@
 # Apache License.
 
 """
-The Stellar Game Engine (abbreviated "SGE", pronounced as "Sage") is a
-free 2-D game engine.  The purpose of the SGE is to make game
-development easier, which allows more rapid development by experienced
-game developers and also helps less experienced game developers learn
-how to develop games.
+The SGE Game Engine ("SGE", pronounced like "Sage") is a general-purpose
+2-D game engine.  It takes care of several details for you so you can
+focus on the game itself.  This makes more rapid game development
+possible, and it also makes the SGE easy to learn.
 
 Official implementations of the SGE are `free/libre software
 <http://gnu.org/philosophy/free-sw.html>`_, and the SGE documentation is
 free/libre as well.
 
-Even if it isn't required, you are encouraged to release your games'
+Although it isn't required, you are encouraged to release your games'
 code under a free/libre software license, such as the GNU General Public
 License, the Expat License, or the Apache License.  Doing so is easy,
 does not negatively affect you, and is highly appreciated as a
@@ -69,61 +68,6 @@ recommended, however, unless you are running your own loop for some
 reason (in which case it is necessary to do this in order to get input
 from the user).
 
-Colors
-------
-
-The SGE accepts a few different formats for defining colors.
-
-The sixteen basic HTML colors, provided as strings, are accepted.  These
-are case-insensitive, so ``"red"`` is interpreted the same as ``"Red"``
-or ``"rEd"``.  The colors are:
-
-- ``"white"``
-- ``"silver"``
-- ``"gray"``
-- ``"black"``
-- ``"red"``
-- ``"maroon"``
-- ``"yellow"``
-- ``"olive"``
-- ``"lime"``
-- ``"green"``
-- ``"aqua"``
-- ``"teal"``
-- ``"blue"``
-- ``"navy"``
-- ``"fuchsia"``
-- ``"purple"``
-
-Tuples containing three or four integers are accepted.  Each index
-represents a component of a color: first red, then green, then blue,
-with the values being integers from ``0`` to ``255``.  For example,
-``(255, 128, 0)`` indicates a color with full red intensity, 50% green
-intensity, and no blue intensity, which is a shade of orange.  Note that
-the components are colors of light, not colors of pigment.
-
-The fourth value of the tuple, if specified, indicates the alpha
-transparency of the color, with the possible values again being integers
-from ``0`` to ``255``.  ``255`` is fully opaque, ``0`` is fully
-transparent, and any value in between indicates the amount of opacity;
-for example, 128 is 50% transparent.  If the fourth value is
-unspecified, it is assumed that the color is fully opaque.
-
-RGBA tuples are the only way to specify alpha transparency of colors in
-SGE.  All other methods for indicating color assume full opacity.
-
-HTML hex strings and integers are accepted.  HTML hex strings are in the
-format ``"#RRGGBB"``, where ``RR``, ``GG``, and ``BB`` are replaced with
-the red, green, and blue components of the color, respectively, in
-hexadecimal form.  ``FF`` (equivalent to 255 in decimal form) is full
-intensity of the respective color, and ``00`` (equivalent to 0 in
-decimal form) is no intensity of the respective color.  For example,
-``"#FF8000"`` is the same as ``(255, 128, 0)``, or orange.
-
-Integers, treated as hexadecimals, are accepted in the same form as HTML
-hex strings, but integral.  For example, ``0xFF8000`` is the same as
-``"#FF8000"``.
-
 Position
 --------
 
@@ -360,10 +304,9 @@ Dependencies
 - [...]
 
 [insert other info here]
-
 """
 
-__version__ = "0.10.1"
+__version__ = "0.11.0"
 
 import sys
 import os
@@ -460,6 +403,7 @@ MOUSE_BUTTON_NAMES = {}
 for pair in MOUSE_BUTTONS.items():
     MOUSE_BUTTON_NAMES[pair[1]] = pair[0]
 
+from sge.Color import Color
 from sge.Game import Game
 from sge.Sprite import Sprite
 from sge.BackgroundLayer import BackgroundLayer
@@ -467,7 +411,7 @@ from sge.Background import Background
 from sge.Font import Font
 from sge.Sound import Sound
 from sge.Music import Music
-from sge.StellarClass import StellarClass, Mouse
+from sge.Object import Object, Mouse
 from sge.Room import Room
 from sge.View import View
 from sge import collision, input, joystick, keyboard, mouse
@@ -486,11 +430,11 @@ __all__ = [
     'BLEND_RGB_MAXIMUM',
 
     # Classes
-    'Game', 'Sprite', 'BackgroundLayer', 'Background', 'Font', 'Sound',
-    'Music', 'StellarClass', 'Room', 'View',
+    'Color', 'Game', 'Sprite', 'BackgroundLayer', 'Background', 'Font',
+    'Sound', 'Music', 'Object', 'Room', 'View',
 
     # Functions
-    'show_message', 'get_text_entry'
+    'show_message', 'get_text_entry',
     ]
 
 # Global variables
